using Microsoft.JSInterop;
using System.Collections.Generic;
using System.Linq; // Added for Enumerable.Empty<string>()
using System.Text.Json; // Added for JsonSerializer

namespace SessionZero.Services;

public class LocalStorageService : ILocalStorageService
{
    private readonly IJSRuntime _jsRuntime;

    public LocalStorageService(IJSRuntime jsRuntime)
    {
        _jsRuntime = jsRuntime;
    }

    public async Task SetItemAsync(string key, string value)
    {
        await _jsRuntime.InvokeVoidAsync("localStorage.setItem", key, value);
    }

    public async Task<string?> GetItemAsync(string key)
    {
        return await _jsRuntime.InvokeAsync<string?>("localStorage.getItem", key);
    }

    public async Task RemoveItemAsync(string key)
    {
        await _jsRuntime.InvokeVoidAsync("localStorage.removeItem", key);
    }

    public async Task<IEnumerable<string>> GetAllKeysAsync()
    {
        // This JavaScript snippet iterates through all keys in localStorage
        // and returns them as a JSON array.
        var jsonKeys = await _jsRuntime.InvokeAsync<string>("eval", @"
            (function() {
                var keys = [];
                for (var i = 0; i < localStorage.length; i++) {
                    keys.push(localStorage.key(i));
                }
                return JSON.stringify(keys);
            })();
        ");

        if (string.IsNullOrEmpty(jsonKeys))
        {
            return Enumerable.Empty<string>();
        }

        // Deserialize the JSON string of keys into a List<string>
        return JsonSerializer.Deserialize<List<string>>(jsonKeys) ?? Enumerable.Empty<string>();
    }
}